import { Hono, Context } from 'hono';
import { PoolConnection } from 'mariadb';
import User from 'slovo/models/User';
import Database from 'slovo/infrastructure/database';

const app = new Hono();

// add routes and methods here
app.post('/register', async (c: Context) => {
    const user: User = await c.req.json<User>();

    const conn: PoolConnection = await Database.getInstance().getConnection();
    const query = `INSERT INTO users (username, name, password) VALUES (?, ?)`;

    try {
        const results = await conn.query(query, [ 
            user.username, 
            user.name,
            user.password
        ]);

        console.log(results);

        await conn.release();

        return c.json({
            message: "Registration successful.",
        });
    } catch (e) {
        console.error(e);
        c.status(500);
        return c.json({
            message: "Error registering user."
        });
    }
});

export default app;
